# JoBase
**Fast Python Game Library**

JoBase is a blazingly fast Python game library for beginner coders.
It is written in pure C and uses OpenGL for rendering.
Please visit [jobase.org](https://jobase.org) to get started.
Our [GitHub Wiki](https://github.com/JoBase/JoBase/wiki) also provides a detailed guide on the features of JoBase.
Please contact us at <hello@jobase.org> with any of your final projects, we may choose to include them in the JoBase package.